package com.fs.company.service;

import java.util.List;
import com.fs.company.domain.CompanySalesPlan;

/**
 * 销售计划Service接口
 * 
 * @author fs
 * @date 2025-07-01
 */
public interface ICompanySalesPlanService 
{
    /**
     * 查询销售计划
     * 
     * @param id 销售计划主键
     * @return 销售计划
     */
    public CompanySalesPlan selectCompanySalesPlanById(Long id);

    /**
     * 查询销售计划列表
     * 
     * @param companySalesPlan 销售计划
     * @return 销售计划集合
     */
    public List<CompanySalesPlan> selectCompanySalesPlanList(CompanySalesPlan companySalesPlan);

    /**
     * 新增销售计划
     * 
     * @param companySalesPlan 销售计划
     * @return 结果
     */
    public int insertCompanySalesPlan(CompanySalesPlan companySalesPlan);

    /**
     * 修改销售计划
     * 
     * @param companySalesPlan 销售计划
     * @return 结果
     */
    public int updateCompanySalesPlan(CompanySalesPlan companySalesPlan);

    /**
     * 批量删除销售计划
     * 
     * @param ids 需要删除的销售计划主键集合
     * @return 结果
     */
    public int deleteCompanySalesPlanByIds(Long[] ids);

    /**
     * 删除销售计划信息
     * 
     * @param id 销售计划主键
     * @return 结果
     */
    public int deleteCompanySalesPlanById(Long id);
}
